aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRapptz <[email protected]>2017-01-26 05:31:11 -0500
committerRapptz <[email protected]>2017-01-26 05:31:11 -0500
commit0e1bd1647e98e9d55a5769899ff6ec365d4ba51f (patch)
tree94357d7cc7bc9bb89f67276ebfcb36d7c97bde61
parent[commands] Allow customising the Context class in get_context. (diff)
downloaddiscord.py-0e1bd1647e98e9d55a5769899ff6ec365d4ba51f.tar.xz
discord.py-0e1bd1647e98e9d55a5769899ff6ec365d4ba51f.zip
[commands] Rename __check to __global_check for cogs.
-rw-r--r--discord/ext/commands/bot.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/discord/ext/commands/bot.py b/discord/ext/commands/bot.py
index 5eb40f1c..bbf0d995 100644
--- a/discord/ext/commands/bot.py
+++ b/discord/ext/commands/bot.py
@@ -369,7 +369,7 @@ class BotBase(GroupMixin):
They are meant as a way to organize multiple relevant commands
into a singular class that shares some state or no state at all.
The cog can also have a ``__check`` member function that allows
you to define a global check. See :meth:`check` for more info.
More information will be documented soon.
@@ -383,7 +383,7 @@ class BotBase(GroupMixin):
self.cogs[type(cog).__name__] = cog
try:
- check = getattr(cog, '_{.__class__.__name__}__check'.format(cog))
+ check = getattr(cog, '_{.__class__.__name__}__global_check'.format(cog))
except AttributeError:
pass
else:
@@ -449,7 +449,7 @@ class BotBase(GroupMixin):
self.remove_listener(member)
try:
- check = getattr(cog, '_{0.__class__.__name__}__check'.format(cog))
+ check = getattr(cog, '_{0.__class__.__name__}__global_check'.format(cog))
except AttributeError:
pass
else:
@@ -369,7 +369,7 @@ class BotBase(GroupMixin):
They are meant as a way to organize multiple relevant commands
into a singular class that shares some state or no state at all.
- The cog can also have a ``__check`` member function that allows
+ The cog can also have a ``__global_check`` member function that allows
you to define a global check. See :meth:`check` for more info.
More information will be documented soon.